﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.AI;
using UnityEngine.UI;

public class Enemy : MonoBehaviour
{
    Engineer engineer;

    NavMeshAgent agent;
    NavMeshHit myNavHit;

    Animator anim;

    Tower[] towers;

    Tower targetTower;

    public int startingHealth;
    int health;

    bool attack;
    bool attackEngineer;

    Image healthBar;

    HUDManager hudManager;
    Manager manager;

    void Start()
    {
        engineer = FindObjectOfType<Engineer>();

        towers = FindObjectsOfType<Tower>();
        health = startingHealth;
        anim = transform.GetChild(0).GetComponent<Animator>();

        agent = GetComponent<NavMeshAgent>();
        if (NavMesh.SamplePosition(transform.position, out myNavHit, 100, -1))
        {
            transform.position = myNavHit.position;
            agent.SetDestination(myNavHit.position);
        }

        healthBar = transform.GetChild(1).GetChild(0).GetChild(0).GetComponent<Image>();
        healthBar.fillAmount = (float)health / startingHealth;

        hudManager = FindObjectOfType<HUDManager>();
        manager = FindObjectOfType<Manager>();

        attack = false;
    }
    
    void Update()
    {
        healthBar.transform.parent.LookAt(new Vector3(transform.position.x, Camera.main.transform.position.y, Camera.main.transform.position.z));
        if (!engineer.IsEngineerDead() && !attack)
        {
            Hunt();
            if(agent.velocity.magnitude > 1)
            {
                if(!anim.GetCurrentAnimatorStateInfo(0).IsName("Move"))
                anim.SetTrigger("Move");
            }
        }
        else if (engineer.IsEngineerDead())
        {
            agent.isStopped = true;
        }
    }

    void Hunt()
    {
        AnimatorStateInfo currentAnimation = anim.GetCurrentAnimatorStateInfo(0);
        float distanceToEngineer = Vector3.Distance(transform.position, engineer.transform.position);
        if (distanceToEngineer < 4.5f)
        {
            if (distanceToEngineer < 2f)
            {
                attackEngineer = true;
                agent.isStopped = true;
                attack = true;
                anim.SetTrigger("Attack");
                Vector3 targetLook = new Vector3(engineer.transform.position.x, transform.position.y, engineer.transform.position.z);
                transform.LookAt(targetLook);
            }
            else if (NavMesh.SamplePosition(engineer.transform.position, out myNavHit, 100, -1))
            {
                agent.SetDestination(myNavHit.position);
                agent.isStopped = false;
            }
            return;
        }
        SetClosestTower();
        float distanceToTower = Vector3.Distance(transform.position, targetTower.transform.position);
        if (distanceToTower <= 2.5f)
        {
            attackEngineer = false;
            agent.isStopped = true;
            attack = true;
            anim.SetTrigger("Attack");
            Vector3 targetLook = new Vector3(targetTower.transform.position.x, transform.position.y, targetTower.transform.position.z);
            transform.LookAt(targetLook);
        }
        else if (NavMesh.SamplePosition(targetTower.transform.position, out myNavHit, 100, -1))
        {
            agent.SetDestination(myNavHit.position);
            agent.isStopped = false;
        }
    }

    void SetClosestTower()
    {
        float distance = 0;
        Tower target = null;
        foreach(Tower tower in towers)
        {
            float tempDistance = Vector3.Distance(transform.position, tower.transform.position);
            if (target == null && tower.HealthAmount() > 0)
            {
                target = tower;
                distance = tempDistance;
            }
            else
            {
                if (tempDistance < distance && tower.HealthAmount() > 0)
                {
                    target = tower;
                    distance = tempDistance;
                }
            }
        }
        targetTower = target;
    }

    public void Damage(int damageAmount)
    {
        health -= damageAmount;
        healthBar.fillAmount = (float)health / startingHealth;
        anim.SetTrigger("Pain");
        attack = false;
        if (health <= 0)
        {
            AudioManager.PlaySound2D("EnemyDying", 1);
            manager.PlayExplosion(transform.position);
            hudManager.AddPoints(5);
            Destroy(gameObject);
        }
    }

    public void Attack()
    {
        float distanceToTarget = 0;
        if (attackEngineer)
        {
            distanceToTarget = Vector3.Distance(transform.position, engineer.transform.position);
            if(distanceToTarget < 2)
            {
                engineer.Damage(15);
            }
        }
        else
        {
            distanceToTarget = Vector3.Distance(transform.position, targetTower.transform.position);
            if (distanceToTarget < 2.5f)
            {
                targetTower.Damage(5);
            }
        }
    }

    public void AttackFinished()
    {
        attack = false;
    }
}
