﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.AI;
using UnityEngine.UI;

public class Engineer : MonoBehaviour
{
    public LayerMask interactible;

    public GameObject hammer;

    NavMeshAgent agent;
    NavMeshHit myNavHit;

    Animator anim;

    Transform hammerPointer;
    Transform launcher;

    int startingHealth;
    int health;

    bool holdingHammer;
    bool repair;
    bool preparingHammer;
    bool engineerDead;

    float holdingHammerSpeed;
    float normalSpeed;
    float afterThrowTimer;

    Tower towerUnderRepair;
    Hammer freeHammer;

    Image healthBar;

    HUDManager hudManager;

    public ParticleSystem clickPS;

    void Start()
    {
        agent = GetComponent<NavMeshAgent>();
        if (NavMesh.SamplePosition(transform.position, out myNavHit, 100, -1))
        {
            transform.position = myNavHit.position;
        }

        anim = transform.GetChild(0).GetComponent<Animator>();

        startingHealth = 100;
        health = startingHealth;

        holdingHammer = false;
        hammer.SetActive(false);

        hammerPointer = transform.GetChild(1);
        hammerPointer.gameObject.SetActive(false);

        launcher = transform.GetChild(2);

        holdingHammerSpeed = 3.05f;
        normalSpeed = 3.8f;

        freeHammer = FindObjectOfType<Hammer>();
        freeHammer.gameObject.SetActive(true);

        healthBar = transform.GetChild(3).GetChild(0).GetChild(0).GetComponent<Image>();
        healthBar.fillAmount = (float)health / startingHealth;

        hudManager = FindObjectOfType<HUDManager>();
    }
    
    void Update()
    {
        healthBar.transform.parent.LookAt(new Vector3(transform.position.x, Camera.main.transform.position.y, Camera.main.transform.position.z));
        if (!engineerDead)
        {
            InputSystem();
            AnimationSystem();
            ClickEffect();
        }
    }

    void AnimationSystem()
    {
        afterThrowTimer -= Time.deltaTime;
        if (!holdingHammer && afterThrowTimer < 0 && Vector3.Distance(transform.position, freeHammer.transform.position) <= 1f)
        {
            holdingHammer = true;
            hammer.SetActive(true);
            freeHammer.HideHammer();
        }

        AnimatorStateInfo currentAnimation = anim.GetCurrentAnimatorStateInfo(0);
        if (!preparingHammer)
        {
            if (repair && towerUnderRepair != null && Vector3.Distance(transform.position, towerUnderRepair.transform.position) <= 2.25f)
            {
                if (!towerUnderRepair.HasFullHealth())
                {
                    if (!currentAnimation.IsName("Repair"))
                        anim.SetTrigger("Repair");
                }
                else
                {
                    if (!currentAnimation.IsName("Idle"))
                        anim.SetTrigger("Idle");
                }
                Vector3 targetLook = new Vector3(towerUnderRepair.transform.position.x, transform.position.y, towerUnderRepair.transform.position.z);
                transform.LookAt(targetLook);
                agent.isStopped = true;
            }
            else if (agent.velocity.magnitude > 1)
            {
                if (holdingHammer)
                {
                    if (!currentAnimation.IsName("RunHammer"))
                        anim.SetTrigger("HammerRun");
                }
                else
                {
                    if (!currentAnimation.IsName("Run"))
                        anim.SetTrigger("Run");
                }
            }
            else
            {
                if (!currentAnimation.IsName("Idle"))
                    anim.SetTrigger("Idle");
            }

            if (holdingHammer)
            {
                agent.speed = holdingHammerSpeed;
            }
            else
            {
                agent.speed = normalSpeed;
            }
        }
    }

    void InputSystem()
    {
        Quaternion targetRotation = Quaternion.LookRotation(transform.transform.position - Camera.main.transform.position);
        Camera.main.transform.rotation = Quaternion.Slerp(Camera.main.transform.rotation, targetRotation, 2 * Time.deltaTime);
        Ray ray = Camera.main.ScreenPointToRay(Input.mousePosition);
        Physics.Raycast(ray, out RaycastHit hit, interactible);
        NavMesh.SamplePosition(hit.point, out myNavHit, 100, -1);

        if (holdingHammer)
        {
            if (Input.GetMouseButtonDown(1))
            {
                agent.isStopped = true;
                hammerPointer.gameObject.SetActive(true);
                anim.SetTrigger("Prepare");
                preparingHammer = true;
                repair = false;
            }
            else if (Input.GetMouseButton(1))
            {
                Vector3 targetLook = new Vector3(hit.point.x, transform.position.y, hit.point.z);
                transform.LookAt(targetLook);
            }
            else if (Input.GetMouseButtonUp(1))
            {
                hammerPointer.gameObject.SetActive(false);
                repair = false;
                afterThrowTimer = 0.5f;
                anim.SetTrigger("Throw");
                holdingHammer = false;
            }
            else if(Input.GetMouseButton(0))
            {
                agent.SetDestination(myNavHit.position);
                agent.isStopped = false;
                if (hit.collider.gameObject.name.Contains("Ground"))
                {
                    repair = false;
                }
                else
                {
                    towerUnderRepair = hit.collider.GetComponent<Tower>();
                    repair = true;
                }
            }
        }
        else
        {
            if (Input.GetMouseButton(0))
            {
                agent.SetDestination(myNavHit.position);

                agent.isStopped = false;
            }
        }
    }

    void ClickEffect()
    {
        if (Input.GetMouseButton(0))
        {
            Ray ray = Camera.main.ScreenPointToRay(Input.mousePosition);
            Physics.Raycast(ray, out RaycastHit hit, interactible);
            NavMesh.SamplePosition(hit.point, out myNavHit, 100, -1);
            clickPS.transform.parent.position = myNavHit.position;
            if(!clickPS.isPlaying)
                clickPS.Play();
        }
        else
        {
            if(clickPS.isPlaying)
                clickPS.Stop();
        }
    }

    public void RepairTower()
    {
        towerUnderRepair.RepairTower(5);
        AudioManager.PlaySound2D("HammerHit", 1);
    }

    public void ThrowHammer()
    {
        hammer.SetActive(false);
        preparingHammer = false;
        freeHammer.ThrowHammer();
        freeHammer.transform.position = launcher.position;
        freeHammer.transform.rotation = launcher.rotation;
    }

    public void Damage(int damageAmount)
    {
        health -= damageAmount;
        healthBar.fillAmount = (float)health / startingHealth;
        if (health <= 0)
        {
            AudioManager.PlaySound2D("CharDying", 1);
            engineerDead = true;
            hudManager.ShowLosingHUD();
            anim.SetTrigger("Die");
        }
        else
        {
            AudioManager.PlaySound2D("TakingHit", 0.5f);
            anim.SetTrigger("Pain");
        }
    }

    public bool IsEngineerDead()
    {
        return engineerDead;
    }
}
