﻿using System.Collections;
using UnityEngine;
using UnityEngine.UI;

public class Tower : MonoBehaviour
{
    public bool centerTower;
    public LayerMask layerMask;
    public int startingHealth;
    int health;

    Transform gunBase;

    float shootingTimer;

    ParticleSystem shotPS;
    ParticleSystem blastPS;

    ParticleSystem deadSmoke_0, deadSmoke_1;

    Transform closestEnemy;

    Image healthBar;

    Animator anim;

    Engineer engineer;
    HUDManager hudManager;

    void Start()
    {
        if (!centerTower)
        {
            gunBase = transform.GetChild(0).GetChild(3).GetChild(0);

            shotPS = gunBase.transform.GetChild(3).GetComponent<ParticleSystem>();
            blastPS = transform.GetChild(0).GetChild(4).GetChild(0).GetComponent<ParticleSystem>();
            anim = transform.GetChild(0).GetComponent<Animator>();

            deadSmoke_0 = transform.GetChild(0).GetChild(3).GetChild(0).GetChild(0).GetChild(1).GetChild(0).GetComponent<ParticleSystem>();
            deadSmoke_1 = transform.GetChild(0).GetChild(3).GetChild(0).GetChild(0).GetChild(1).GetChild(1).GetComponent<ParticleSystem>();
        }
        else
        {
            hudManager = FindObjectOfType<HUDManager>();
        }

        health = Random.Range(70, 101);

        healthBar = transform.GetChild(1).GetChild(0).GetChild(0).GetComponent<Image>();
        healthBar.fillAmount = (float)health / startingHealth;

        engineer = FindObjectOfType<Engineer>();
    }

    void Update()
    {
        healthBar.transform.parent.LookAt(new Vector3(transform.position.x, Camera.main.transform.position.y, Camera.main.transform.position.z));
        if (!engineer.IsEngineerDead() && health > 0 && !centerTower)
        {
            if (closestEnemy == null)
            {
                Collider[] enemiesOnRange = Physics.OverlapSphere(transform.position, 5f, layerMask);
                if (enemiesOnRange.Length > 0)
                {
                    float distance = 0;
                    foreach (Collider enemy in enemiesOnRange)
                    {
                        if (closestEnemy == null)
                        {
                            closestEnemy = enemy.transform;
                            distance = Vector3.Distance(enemy.transform.position, gunBase.position);
                        }
                        else
                        {
                            float tempDist = Vector3.Distance(enemy.transform.position, gunBase.position);
                            if (tempDist < distance)
                            {
                                distance = tempDist;
                                closestEnemy = enemy.transform;
                            }
                        }
                    }
                }
            }
            else
            {
                Vector3 enemyHead = new Vector3(closestEnemy.position.x, 1.5f, closestEnemy.transform.position.z);
                Vector3 lookPos = enemyHead - gunBase.position;
                lookPos.y = 0;
                Quaternion rotation = Quaternion.LookRotation(lookPos);
                Quaternion targetRotation = Quaternion.Euler(-90, 0, rotation.eulerAngles.y - 90);
                gunBase.rotation = Quaternion.Lerp(gunBase.rotation, targetRotation, Time.deltaTime * 10f);

                shootingTimer -= Time.deltaTime;
                float yRotationToTarget = Quaternion.Angle(gunBase.rotation, targetRotation);
                if (shootingTimer <= 0 && yRotationToTarget <= 0.05f)
                {
                    shootingTimer = 1.5f;
                    StartCoroutine(BlastEnemy(0.1f, closestEnemy.position, closestEnemy));
                    shotPS.Play();
                    AudioManager.PlaySound2D("TowerPews", 0.6f);
                    anim.SetTrigger("Shoot");
                }
            }

            if (deadSmoke_0.isPlaying && health > 0)
            {
                deadSmoke_0.Stop();
                deadSmoke_1.Stop();
            }
        }
    }

    IEnumerator BlastEnemy(float delay, Vector3 position, Transform enemy)
    {
        yield return new WaitForSeconds(delay);
        blastPS.transform.position = position;
        blastPS.Play();
        if (enemy != null)
            enemy.GetComponent<Enemy>().Damage(10);
    }

    public void RepairTower(int repairAmount)
    {
        if (health < startingHealth)
        {
            if (health + repairAmount > startingHealth)
                health = startingHealth;
            else
                health += repairAmount;
        }
        healthBar.fillAmount = (float)health / startingHealth;
    }

    public bool HasFullHealth()
    {
        return health == startingHealth ? true : false;
    }

    public void Damage(int damageAmount)
    {
        health -= damageAmount;
        healthBar.fillAmount = (float)health / startingHealth;
        if (health < 0)
        {
            if (centerTower)
            {
                hudManager.ShowLosingHUD();
                engineer.Damage(1000);
            }
            else
            {
                health = 0;
                deadSmoke_0.Play();
                deadSmoke_1.Play();
            }
        }
    }

    public int HealthAmount()
    {
        return health;
    }

    private void OnDrawGizmos()
    {
        if (!centerTower)
        {
            Gizmos.color = Color.red;
            Gizmos.DrawWireSphere(transform.position, 5f);
        }
    }
}
